@@ -74,6 +74,8 @@ pub mod paginated_janus_cloud_stream_list;
 pub use self::paginated_janus_cloud_stream_list::PaginatedJanusCloudStreamList;
 pub mod paginated_janus_edge_stream_list;
 pub use self::paginated_janus_edge_stream_list::PaginatedJanusEdgeStreamList;
+pub mod paginated_janus_stream_list;
+pub use self::paginated_janus_stream_list::PaginatedJanusStreamList;
 pub mod paginated_octo_print_backup_list;
 pub use self::paginated_octo_print_backup_list::PaginatedOctoPrintBackupList;
 pub mod paginated_octo_print_settings_list;
